@@ -4,20 +4,30 @@ configure a Kedro project and access its settings."""
 import importlib
 import logging.config
 import operator
+import os
 import sys
+import traceback
+import types
+import warnings
 from collections import UserDict
 from collections.abc import MutableMapping
 from pathlib import Path
 from typing import Any, Dict, Optional
 
 import click
+import importlib_resources
 import rich.pretty
 import rich.traceback
 import yaml
 from dynaconf import LazySettings
 from dynaconf.validator import ValidationError, Validator
 
-from kedro.pipeline import Pipeline
+from kedro.pipeline import Pipeline, pipeline
+
+IMPORT_ERROR_MESSAGE = (
+    "An error occurred while importing the '{module}' module. Nothing "
+    "defined therein will be returned by 'find_pipelines'.\n\n{tb_exc}"
+)
 
 
 def _get_default_class(class_import_path):
@@ -150,7 +160,7 @@ class _ProjectPipelines(MutableMapping):
         return register_pipelines
 
     def _load_data(self):
-        """Lazily read pipelines defined in the pipelines registry module"""
+        """Lazily read pipelines defined in the pipelines registry module."""
 
         # If the pipelines dictionary has not been configured with a pipelines module
         # or if data has been loaded
@@ -167,7 +177,7 @@ class _ProjectPipelines(MutableMapping):
 
     def configure(self, pipelines_module: Optional[str] = None) -> None:
         """Configure the pipelines_module to load the pipelines dictionary.
-        Reset the data loading state so that after every `configure` call,
+        Reset the data loading state so that after every ``configure`` call,
         data are reloaded.
         """
         self._pipelines_module = pipelines_module
@@ -199,14 +209,17 @@ class _ProjectLogging(UserDict):
 
         # We suppress click here to hide tracebacks related to it conversely,
         # kedro is not suppressed to show its tracebacks for easier debugging.
-        # sys.executable is used to get the kedro executable path to hide the top level traceback.
-        rich.traceback.install(
-            show_locals=True, suppress=[click, str(Path(sys.executable).parent)]
-        )
+        # sys.executable is used to get the kedro executable path to hide the
+        # top level traceback.
+        # Rich traceback handling does not work on databricks. Hopefully this will be
+        # fixed on their side at some point, but until then we disable it.
+        # See https://github.com/Textualize/rich/issues/2455
+        if "DATABRICKS_RUNTIME_VERSION" not in os.environ:
+            rich.traceback.install(suppress=[click, str(Path(sys.executable).parent)])
         rich.pretty.install()
 
     def configure(self, logging_config: Dict[str, Any]) -> None:
-        """Configure project logging using `logging_config` (e.g. from project
+        """Configure project logging using ``logging_config`` (e.g. from project
         logging.yml). We store this in the UserDict data so that it can be reconfigured
         in _bootstrap_subprocess.
         """
@@ -241,7 +254,7 @@ def configure_project(package_name: str):
 
 
 def configure_logging(logging_config: Dict[str, Any]) -> None:
-    """Configure logging according to `logging_config` dictionary."""
+    """Configure logging according to ``logging_config`` dictionary."""
     LOGGING.configure(logging_config)
 
 
@@ -253,4 +266,104 @@ def validate_settings():
     error message ``Expected an instance of `ConfigLoader`, got `NoneType` instead``.
     More info on the dynaconf issue: https://github.com/rochacbruno/dynaconf/issues/460
     """
+    if PACKAGE_NAME is None:
+        raise ValueError(
+            "Package name not found. Make sure you have configured the project using "
+            "'bootstrap_project'. This should happen automatically if you are using "
+            "Kedro command line interface."
+        )
+
     importlib.import_module(f"{PACKAGE_NAME}.settings")
+
+
+def _create_pipeline(pipeline_module: types.ModuleType) -> Optional[Pipeline]:
+    if not hasattr(pipeline_module, "create_pipeline"):
+        warnings.warn(
+            f"The '{pipeline_module.__name__}' module does not "
+            f"expose a 'create_pipeline' function, so no pipelines "
+            f"defined therein will be returned by 'find_pipelines'."
+        )
+        return None
+
+    obj = getattr(pipeline_module, "create_pipeline")()
+    if not isinstance(obj, Pipeline):
+        warnings.warn(
+            f"Expected the 'create_pipeline' function in the "
+            f"'{pipeline_module.__name__}' module to return a "
+            f"'Pipeline' object, got '{type(obj).__name__}' "
+            f"instead. Nothing defined therein will be returned by "
+            f"'find_pipelines'."
+        )
+        return None
+
+    return obj
+
+
+def find_pipelines() -> Dict[str, Pipeline]:
+    """Automatically find modular pipelines having a ``create_pipeline``
+    function. By default, projects created using Kedro 0.18.3 and higher
+    call this function to autoregister pipelines upon creation/addition.
+
+    Projects that require more fine-grained control can still define the
+    pipeline registry without calling this function. Alternatively, they
+    can modify the mapping generated by the ``find_pipelines`` function.
+
+    For more information on the pipeline registry and autodiscovery, see
+    https://kedro.readthedocs.io/en/latest/nodes_and_pipelines/pipeline_registry.html
+
+    Returns:
+        A generated mapping from pipeline names to ``Pipeline`` objects.
+
+    Warns:
+        UserWarning: When a module does not expose a ``create_pipeline``
+            function, the ``create_pipeline`` function does not return a
+            ``Pipeline`` object, or if the module import fails up front.
+    """
+    pipeline_obj = None
+
+    # Handle the simplified project structure found in several starters.
+    pipeline_module_name = f"{PACKAGE_NAME}.pipeline"
+    try:
+        pipeline_module = importlib.import_module(pipeline_module_name)
+    except Exception as exc:  # pylint: disable=broad-except
+        if str(exc) != f"No module named '{pipeline_module_name}'":
+            warnings.warn(
+                IMPORT_ERROR_MESSAGE.format(
+                    module=pipeline_module_name, tb_exc=traceback.format_exc()
+                )
+            )
+    else:
+        pipeline_obj = _create_pipeline(pipeline_module)
+
+    pipelines_dict = {"__default__": pipeline_obj or pipeline([])}
+
+    # Handle the case that a project doesn't have a pipelines directory.
+    try:
+        pipelines_package = importlib_resources.files(f"{PACKAGE_NAME}.pipelines")
+    except ModuleNotFoundError as exc:
+        if str(exc) == f"No module named '{PACKAGE_NAME}.pipelines'":
+            return pipelines_dict
+
+    for pipeline_dir in pipelines_package.iterdir():
+        if not pipeline_dir.is_dir():
+            continue
+
+        pipeline_name = pipeline_dir.name
+        if pipeline_name == "__pycache__":
+            continue
+
+        pipeline_module_name = f"{PACKAGE_NAME}.pipelines.{pipeline_name}"
+        try:
+            pipeline_module = importlib.import_module(pipeline_module_name)
+        except:  # pylint: disable=bare-except  # noqa: E722
+            warnings.warn(
+                IMPORT_ERROR_MESSAGE.format(
+                    module=pipeline_module_name, tb_exc=traceback.format_exc()
+                )
+            )
+            continue
+
+        pipeline_obj = _create_pipeline(pipeline_module)
+        if pipeline_obj is not None:
+            pipelines_dict[pipeline_name] = pipeline_obj
+    return pipelines_dict
